@@ -152,8 +152,8 @@ def summarize_dependency_mapping(data, deps, build_deps, resolved_deps):
         return
     info("Package '" + data['Package'] + "' has dependencies:")
     header = "  " + ansi('boldoff') + ansi('ulon') + \
-             "rosdep key           => " + data['Distribution'] + \
-             " key" + ansi('reset')
+             "rosdep key           => " + data['OSName'] + ' ' + \
+             data['Distribution'] + " key" + ansi('reset')
     template = "  " + ansi('cyanf') + "{0:<20} " + ansi('purplef') + \
                "=> " + ansi('cyanf') + "{1}" + ansi('reset')
     if len(deps) != 0:
@@ -208,9 +208,11 @@ def generate_substitutions_from_package(
     rpm_inc=0,
     peer_packages=None,
     releaser_history=None,
-    fallback_resolver=None
+    fallback_resolver=None,
+    skip_keys=None
 ):
     peer_packages = peer_packages or []
+    skip_keys = skip_keys or set()
     data = {}
     # Name, Version, Description
     data['Name'] = package.name
@@ -235,17 +237,21 @@ def generate_substitutions_from_package(
     evaluate_package_conditions(package, ros_distro)
     depends = [
         dep for dep in (package.run_depends + package.buildtool_export_depends)
-        if dep.evaluated_condition is not False]
+        if dep.evaluated_condition is not False and dep.name not in skip_keys]
     build_depends = [
         dep for dep in (package.build_depends + package.buildtool_depends + package.test_depends)
+        if dep.evaluated_condition is not False and dep.name not in skip_keys]
+    replaces = [
+        dep for dep in package.replaces
         if dep.evaluated_condition is not False]
-    unresolved_keys = [
-        dep for dep in (depends + build_depends + package.replaces + package.conflicts)
+    conflicts = [
+        dep for dep in package.conflicts
         if dep.evaluated_condition is not False]
+    unresolved_keys = depends + build_depends + replaces + conflicts
     # The installer key is not considered here, but it is checked when the keys are checked before this
     resolved_deps = resolve_dependencies(unresolved_keys, os_name,
                                          os_version, ros_distro,
-                                         peer_packages + [d.name for d in package.replaces + package.conflicts],
+                                         peer_packages + [d.name for d in (replaces + conflicts)],
                                          fallback_resolver)
     data['Depends'] = sorted(
         set(format_depends(depends, resolved_deps))
@@ -254,11 +260,13 @@ def generate_substitutions_from_package(
         set(format_depends(build_depends, resolved_deps))
     )
     data['Replaces'] = sorted(
-        set(format_depends(package.replaces, resolved_deps))
+        set(format_depends(replaces, resolved_deps))
     )
     data['Conflicts'] = sorted(
-        set(format_depends(package.conflicts, resolved_deps))
+        set(format_depends(conflicts, resolved_deps))
     )
+    data['Provides'] = []
+    data['Supplements'] = []
 
     # Build-type specific substitutions.
     build_type = package.get_build_type()
@@ -275,7 +283,8 @@ def generate_substitutions_from_package(
             "Build type '{}' is not supported by this version of bloom.".
             format(build_type), exit=True)
 
-    # Set the distribution
+    # Set the OS and distribution
+    data['OSName'] = os_name
     data['Distribution'] = os_version
     # Use the time stamp to set the date strings
     stamp = datetime.datetime.now(tz.tzlocal())
@@ -444,7 +453,7 @@ def sanitize_package_name(name):
 class RpmGenerator(BloomGenerator):
     title = 'rpm'
     description = "Generates RPMs from the catkin meta data"
-    has_run_rosdep = False
+    has_run_rosdep = os.environ.get('BLOOM_SKIP_ROSDEP_UPDATE', '0').lower() not in ['0', 'f', 'false', 'n', 'no']
     default_install_prefix = '/usr'
     rosdistro = os.environ.get('ROS_DISTRO', 'indigo')
 
@@ -464,12 +473,16 @@ class RpmGenerator(BloomGenerator):
             help="overrides the default installation prefix (/usr)")
         add('--os-name', default='fedora',
             help="overrides os_name, set to 'fedora' by default")
+        add('--skip-keys', nargs='+', required=False, default=[],
+            help="dependency keys which should be skipped and"
+                 " discluded from the RPM dependencies")
 
     def handle_arguments(self, args):
         self.interactive = args.interactive
         self.rpm_inc = args.rpm_inc
         self.os_name = args.os_name
         self.distros = args.distros
+        self.skip_keys = args.skip_keys or set()
         if self.distros in [None, []]:
             index = rosdistro.get_index(rosdistro.get_index_url())
             distribution_file = rosdistro.get_distribution_file(index, self.rosdistro)
@@ -509,6 +522,7 @@ class RpmGenerator(BloomGenerator):
     def summarize(self):
         info("Generating source RPMs for the packages: " + str(self.names))
         info("RPM Incremental Version: " + str(self.rpm_inc))
+        info("RPM OS: " + str(self.os_name))
         info("RPM Distributions: " + str(self.distros))
 
     def get_branching_arguments(self):
@@ -541,6 +555,14 @@ class RpmGenerator(BloomGenerator):
             for key in keys:
                 key_to_packages_which_depends_on[key].append(package.name)
 
+        for skip_key in self.skip_keys:
+            try:
+                keys_to_resolve.remove(skip_key)
+            except ValueError:
+                warning("Key '{0}' specified by --skip-keys was not found".format(skip_key))
+            else:
+                warning("Skipping dependency key '{0}' per --skip-keys".format(skip_key))
+
         os_name = self.os_name
         rosdistro = self.rosdistro
         all_keys_valid = True
@@ -581,6 +603,8 @@ class RpmGenerator(BloomGenerator):
 
         while not self._check_all_keys_are_valid(peer_packages, self.rosdistro):
             error("Some of the dependencies for packages in this repository could not be resolved by rosdep.")
+            if not self.interactive:
+                sys.exit(code.GENERATOR_NO_ROSDEP_KEY_FOR_DISTRO)
             error("You can try to address the issues which appear above and try again if you wish, "
                   "or continue without releasing into RPM-based distributions (e.g. Fedora 24).")
             try:
@@ -679,8 +703,8 @@ class RpmGenerator(BloomGenerator):
         info(ansi(color) + "####" + ansi('reset'), use_prefix=False)
         info(
             ansi(color) + "#### " + ansi('greenf') + "Successfully" +
-            ansi(color) + " generated '" + ansi('boldon') + distro +
-            ansi('boldoff') + "' RPM for package"
+            ansi(color) + " generated '" + ansi('boldon') + self.os_name +
+            ' ' + distro + ansi('boldoff') + "' RPM for package"
             " '" + ansi('boldon') + package.name + ansi('boldoff') + "'" +
             " at version '" + ansi('boldon') + package.version +
             "-" + str(self.rpm_inc) + ansi('boldoff') + "'" +
@@ -750,11 +774,12 @@ class RpmGenerator(BloomGenerator):
             self.rpm_inc,
             [p.name for p in self.packages.values()],
             releaser_history=releaser_history,
-            fallback_resolver=missing_dep_resolver
+            fallback_resolver=missing_dep_resolver,
+            skip_keys=self.skip_keys
         )
 
     def generate_rpm(self, package, rpm_distro, rpm_dir='rpm'):
-        info("Generating RPM for {0}...".format(rpm_distro))
+        info("Generating RPM for {0} {1}...".format(self.os_name, rpm_distro))
         # Try to retrieve the releaser_history
         releaser_history = self.get_releaser_history()
         # Generate substitution values
@@ -800,8 +825,8 @@ class RpmGenerator(BloomGenerator):
     def summarize_package(self, package, distro, color='bluef'):
         info(ansi(color) + "\n####" + ansi('reset'), use_prefix=False)
         info(
-            ansi(color) + "#### Generating '" + ansi('boldon') + distro +
-            ansi('boldoff') + "' RPM for package"
+            ansi(color) + "#### Generating '" + ansi('boldon') + self.os_name +
+            ' ' + distro + ansi('boldoff') + "' RPM for package"
             " '" + ansi('boldon') + package.name + ansi('boldoff') + "'" +
             " at version '" + ansi('boldon') + package.version +
             "-" + str(self.rpm_inc) + ansi('boldoff') + "'" +
